@@ -9,7 +9,7 @@ function(forn,
      Cairo=TRUE,
      printgraph=TRUE,
      legend="Dummy legend name",
-     diagnose=FALSE, verbose=TRUE)
+     verbose=TRUE)
 {
      #                          plotdiag.params.fixed
      #
@@ -36,17 +36,17 @@ function(forn,
                      cap,
                      filewidth=5, fileheight=5,
                      legendname,
-                     diagnose,verbose)
+                     verbose)
      {
 
           XVAR <- data[,xcol]
           YVAR <- data[,ycol]
           COV1 <- data[,cov1col]
           dfplot <- data.frame(XVAR,YVAR,COV1)
-                      if(diagnose)Hmisc::prn(dfplot)
+#                      if(diagnose)Hmisc::prn(dfplot)
           FACET <- data[,facetcol]
           dfplot <- data.frame(dfplot,FACET)
-                     if(diagnose)Hmisc::prn(dfplot)
+#                     if(diagnose)Hmisc::prn(dfplot)
           out <- ggplot2::ggplot(data=dfplot,ggplot2::aes(XVAR,YVAR,COV1)) + ggplot2::geom_point(ggplot2::aes(shape = COV1))
           out$labels$shape <- legendname
 
@@ -108,8 +108,7 @@ function(forn,
                col2 <- df3
                col3 <- "1"                       # default for only 1 coefficient
                betacoeffs <- as.data.frame(tibble::tibble(col1,col2,col3))
-                                  if(diagnose) Hmisc::prn(betacoeffs)
-
+#                                  if(diagnose) Hmisc::prn(betacoeffs)
                wmf2 <- paste(wmf,".wmf",sep="")    
                ##############################################
                # Call for plot using support function above #
@@ -121,7 +120,7 @@ function(forn,
                      vertlabel="Estimated beta coefficient",
                      cap=caption,
                      legendname=legend,
-                     diagnose=diagnose,verbose=verbose)
+                     verbose=verbose)
 
           }
           else{
@@ -135,7 +134,7 @@ function(forn,
                     col3 <- c(col3,rep(namesdf3[i],times=nrows))
                }    #  i
                betacoeffs <- as.data.frame(tibble::tibble(col1,col2,col3))
-                                  if(diagnose) Hmisc::prn(betacoeffs)
+#                                  if(diagnose) Hmisc::prn(betacoeffs)
                wmf2 <- paste(wmf,".wmf",sep="")    
                ##############################################
                # Call for plot using support function above #
@@ -148,7 +147,7 @@ function(forn,
                      vertlabel="Estimated beta coefficients",
                      cap=caption,
                      legendname=legend,
-                     diagnose=diagnose,verbose=verbose)
+                     verbose=verbose)
 
           }    # else for is null cols
      }
